@@ -13,4 +13,4 @@ The different modules are document here:
 """
 
 from .points import Point3D, Point2D
-from .calib import Calib, parameters_to_affine_transform, compute_rotation_matrix
+from .calib import Calib, parameters_to_affine_transform, compute_rotation_matrix, line_plane_intersection
